/**
 * @license
 * Copyright 2018 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

import summary from "rollup-plugin-summary";
import { terser } from "rollup-plugin-terser";
import resolve from "@rollup/plugin-node-resolve";
import replace from "@rollup/plugin-replace";
import { getBabelOutputPlugin } from "@rollup/plugin-babel";
import minifyHTML from "rollup-plugin-minify-html-literals";
export default {
  input: "./transpiled/dev-console-widget.js",
  output: {
    file: "./build/dev-console-widget.bundle.js",
    format: "esm",
  },
  onwarn(warning) {
    if (warning.code !== "THIS_IS_UNDEFINED") {
      console.error(`(!) ${warning.message}`);
    }
  },
  plugins: [
    replace({ "Reflect.decorate": "undefined", preventAssignment: true }),
    getBabelOutputPlugin({
      presets: ["@babel/preset-env"],
    }),
    resolve(),
    minifyHTML(),
    terser({
      ecma: 2017,
      module: true,
      warnings: true,
      mangle: {
        properties: {
          regex: /^__/,
        },
      },
    }),
    summary(),
  ],
};
